@@ -45,3 +45,5 @@ from .mpro import MProVictor
 from .mpro import data as mpro_data
 from . import branding
 from .display import display_mols, MolNGLWidget
+from .error import FragmensteinError, DistanceError, ShoddyCodeError, PoisonError
+from .faux_victors import Wictor, Quicktor  # the rest are mostly experiments
