@@ -2,6 +2,7 @@
 These are common functions moved out of Victor and Igor to reduce duplication.
 """
 import logging
+import warnings
 
 from rdkit import Chem
 from typing import Tuple, Union, Callable
@@ -60,8 +61,8 @@ def find_attachment(pdb: Chem.Mol, ligand_resn: str) -> Tuple[Union[Chem.Atom, N
     return attachment, attachee
 
 
-get_atomname: Callable[[Chem.Atom], str] = lambda atom: atom.GetPDBResidueInfo().GetName()
-
+def get_atomname(atom: Chem.Atom) -> str:
+    return atom.GetPDBResidueInfo().GetName()
 
 def get_equivalent(template_atom: Chem.Atom, query_mol: Chem.Mol) -> Chem.Atom:
     """
@@ -71,6 +72,34 @@ def get_equivalent(template_atom: Chem.Atom, query_mol: Chem.Mol) -> Chem.Atom:
         lambda mol, name: [atom for atom in mol.GetAtoms() if get_atomname(atom)[:4] == name[:4]][0]
     return get_by_atomname(query_mol, get_atomname(template_atom))
 
+def combine_for_bondorder(template: Chem.Mol, target: Chem.Mol) -> Chem.Mol:
+    target2template = {}
+    for template_ai, template_atom in enumerate(template.GetAtoms()):
+        target_atom: Chem.Atom = get_equivalent(template_atom, target)
+        target_ai: int = target_atom.GetIdx()
+        assert target_ai not in target2template.keys(), f'The atom name {get_atomname(target_atom)} is duplicated '+\
+                                                   f'in the template {get_atomname(template_atom)} & '+\
+                                                   f'{get_atomname(template.GetAtomWithIdx(target2template[target_ai]))}'
+        target2template[target_ai] = template_ai
+    new = Chem.Mol(template)
+    # fix coordinates
+    conf: Chem.Conformer = new.GetConformer()
+    donor_conf: Chem.Conformer = target.GetConformer()
+    for target_ai, template_ai in target2template.items():
+        conf.SetAtomPosition(template_ai, donor_conf.GetAtomPosition(target_ai))
+    # fix props
+    for prop, value in target.GetPropsAsDict().items():
+        if not new.HasProp(prop):
+            new.SetProp(prop, value)
+    for target_ai, new_ai in target2template.items():
+        target_atom = target.GetAtomWithIdx(target_ai)
+        new_atom = new.GetAtomWithIdx(new_ai)
+        for prop, value in target_atom.GetPropsAsDict().items():
+            if new_atom.HasProp(prop):
+                continue
+            new_atom.SetProp(prop, value)
+    return new
+
 
 def copy_bonds_by_atomnames(template: Chem.Mol, target: Chem.Mol) -> bool:
     """
@@ -82,6 +111,7 @@ def copy_bonds_by_atomnames(template: Chem.Mol, target: Chem.Mol) -> bool:
 
     Plus ``PDBResidueInfo`` is lost by ``AllChem.AssignBondOrdersFromTemplate``
     """
+    warnings.warn('This is not used anymore, but kept for reference', DeprecationWarning)
     successful = True
     for template_bond in template.GetBonds():  # type: Chem.Bond
         begin: Chem.Atom = template_bond.GetBeginAtom()
@@ -91,13 +121,25 @@ def copy_bonds_by_atomnames(template: Chem.Mol, target: Chem.Mol) -> bool:
         if query_bond is None:
             # This is due to the molecule being pulled apart at a ring closure.
             # A common issue with RNA minisation too.
-            log.error(f'{get_atomname(begin)} and {get_atomname(end)} are' + \
+            print(f'{get_atomname(begin)} and {get_atomname(end)} are' + \
                              ' bonded in the params but not the minimised: this is a Rosetta glitch')
             successful = False
             continue
         query_bond.SetBondType(template_bond.GetBondType())
         # heme will have crash upstream though:
         query_bond.SetBondDir(template_bond.GetBondDir())
+    for template_atom in template.GetAtoms():
+        target_atom: Chem.Atom = get_equivalent(template_atom, target)
+        #print(get_atomname(template_atom), get_atomname(target_atom))
+        target_atom.SetIsAromatic(template_atom.GetIsAromatic())
+        target_atom.SetIsotope(template_atom.GetIsotope())
+        target_atom.SetFormalCharge(template_atom.GetFormalCharge())
+        target_atom.SetChiralTag(template_atom.GetChiralTag())
+        target_atom.SetNumRadicalElectrons(template_atom.GetNumRadicalElectrons())
+        target_atom.SetNumExplicitHs(template_atom.GetNumExplicitHs())
+        target_atom.SetHybridization(template_atom.GetHybridization())
+        target_atom.SetAtomMapNum(template_atom.GetAtomMapNum())
+    # problem here:
     target.UpdatePropertyCache(strict=False)
     Chem.SanitizeMol(target)
     return successful
