@@ -38,10 +38,10 @@ def unbinarize(bin: bytes, ignore_errors:bool=True) -> Union[Chem.Mol, None]:
     exception = Exception if ignore_errors else ()
     if isinstance(bin, Chem.Mol):  # lol
         return bin
-    if isinstance(bin, float):  # nan
-        return None
-    if bin is None:
+    elif not isinstance(bin, bytes) and ignore_errors:
         return None
+    elif not isinstance(bin, bytes):
+        raise TypeError('the molecule binary provide is not a bytes')
     try:
         return Chem.Mol(bin)
     except KeyboardInterrupt as err:
@@ -54,12 +54,18 @@ class LabBench:
     # the ``outcome`` column in the pandas dataframe can have these values in order of niceness:
     category_labels = ['crashed', 'too distant', 'timeout', 'unstable', 'equally sized', 'deviant', 'acceptable']
 
-    def __init__(self, pdbblock: str, covalent_resi: Union[int, str, None]):
+    def __init__(self, pdbblock: str,
+                 covalent_resi: Union[int, str, None] = None,
+                 ligand_resi: Union[str, None]=None,
+                 run_plip: bool=False,
+                 ):
         self.pdbblock = pdbblock
         self.covalent_resi = covalent_resi
         self.init_options = '-ex1 -ex2 -no_optH false -mute all -ignore_unrecognized_res true -load_PDB_components false'
         self.raw_results = []
+        self.ligand_resi = ligand_resi
         self.Victor = Victor  # So it can be swapped for a subclass w/o the need to subclass Laboratory
+        self.run_plip = run_plip
         if not len(Victor.journal.handlers):
             Victor.enable_stdout(logging.CRITICAL)
 
@@ -91,18 +97,16 @@ class LabBench:
                 print('Keyboard!')
                 self.raw_results.append({'error': 'KeyboardInterrupt', 'name': ''})
                 break
-            except KeyboardInterrupt as err:
-                raise err
             except Exception as error:
                 Victor.journal.error(f'{error.__class__.__name__}: {error}')
                 self.raw_results.append({'error': error.__class__.__name__, 'name': ''})
         # list of dict to dataframe
         df = pd.DataFrame(self.raw_results)
-        if len(df) or '∆∆G' not in df.columns:
+        if not len(df) or '∆∆G' not in df.columns:
             Victor.journal.critical('No results were found. Returning an empty dataframe.')
             return df
         df['LE'] = df.apply(
-            lambda row: row['∆∆G'] / (row.N_constrained_atoms + row.N_unconstrained_atoms),
+            lambda row: - row['∆∆G'] / (row.N_constrained_atoms + row.N_unconstrained_atoms),
             axis=1)
         nan_to_list = lambda value: value if isinstance(value, list) else []
         df['disregarded'] = df.disregarded.apply(nan_to_list)  # str
@@ -110,33 +114,41 @@ class LabBench:
         df['unminimized_mol'] = df.unmin_binary.apply(unbinarize)
         df['minimized_mol'] = df.min_binary.apply(unbinarize)
         df['hit_mols'] = df.hit_binaries.apply(lambda l: [unbinarize(b) for b in l] if isinstance(l, Sequence) else [])
-        df['outcome'] = df.apply(self.categorize, axis=1)
         df['percent_hybrid'] = df.unminimized_mol.apply(self.percent_hybrid)
         return df
 
-    def categorize(self, row: pd.Series) -> str:
+    def categorize(self,
+                   row: pd.Series,
+                   size_tolerance: int=0,
+                   move_cutoff:float=1.,
+                   ddG_cutoff:float=0.,
+                   ) -> str:
         """
         Given a row categorise the 'outcome' field.
         Called by ``get_completed``.
 
+        size_tolerance is the number of atoms below the largest hit that is still acceptable.
+        move_cutoff is the RMSD of the minimized molecules. Below this is acceptable.
+        ddG_cutoff is the ∆∆G of the minimized molecules. Below this is acceptable.
+
         Subclass Laboratory to change what the outcome field ends up being.
         But do remember to update the ``category_labels`` attribute.
         """
         # see category_labels for list of values.
         is_filled: Callable[[Any], int] = lambda value: len(value) != 0 if hasattr(value, '__len__') else False
-        if is_filled(row.disregarded) or 'ConnectionError' in row.error:
+        if is_filled(row.disregarded) or 'DistanceError' in row.error:
             # either is the same thing, but the Victor error catching makes them different
             return 'too distant'
         elif 'TimeoutError' in row.error:
             return 'timeout'
         elif is_filled(row.error):
             return 'crashed'
-        elif max(map(operator.methodcaller('GetNumHeavyAtoms'), row.hit_mols))  \
+        elif max(map(operator.methodcaller('GetNumHeavyAtoms'), row.hit_mols)) - size_tolerance  \
                 >= row.unminimized_mol.GetNumHeavyAtoms():
             return 'equally sized'
-        elif row.comRMSD > 1:
+        elif row.comRMSD > move_cutoff:
             return 'too moved'
-        elif row['∆∆G'] >= 0:
+        elif row['∆∆G'] >= ddG_cutoff:
             return 'too contorted'
         else:
             return 'acceptable'
