@@ -20,6 +20,20 @@ if sys.version_info.major != 3 or sys.version_info.minor < 8:
     typing.overload = overload  # noqa
 if sys.version_info.major != 3 or sys.version_info.minor < 11:
     # Unpack allows clean annotation of **kwargs!
-    from typing_extensions import Unpack  # this was only "recently" added... if you get an error: upgrade package
+    from typing_extensions import Unpack, NotRequired
+    # this was only "recently" added... if you get an error: upgrade package typing_extensions
     import typing
     typing.Unpack = Unpack
+    typing.NotRequired = NotRequired
+
+
+# NGLView has been broken for a while. This is a hack to ignore it.
+# the issue stems from widgets 7 to 8.
+try:
+    import nglview
+except Exception as err:
+    from unittest.mock import MagicMock
+    import sys
+
+    sys.modules['nglview'] = MagicMock()
+    sys.modules['nglview.component'] = MagicMock()
