@@ -6,12 +6,15 @@ from ..mcs_mapping import IndexMap, ExtendedFMCSMode
 from copy import deepcopy
 from rdkit import Chem
 from ..unmerge_mapper import Unmerge
+from ...error import FragmensteinError, DistanceError
+
 
 class _MonsterExpand(_MonsterNone):
     """
     A variant of no_blend mode, with a focus on expansion
     """
-    def by_expansion(self, primary_name:Optional[str]=None, min_mode_index:int=0) -> Chem.Mol:
+
+    def by_expansion(self, primary_name: Optional[str] = None, min_mode_index: int = 0) -> Chem.Mol:
         """
         Get the maps. Find the map with the most atoms covered.
         Use that map as the base map for the other maps.
@@ -24,15 +27,68 @@ class _MonsterExpand(_MonsterNone):
         # positional_overlap is used by ``_expand_hit_atom_map_by_overlap``
         # which is called by ``_get_unmerge_expansions``
         positional_overlaps: Dict[Tuple[str, str], Dict[int, int]] = self._compute_overlaps()
+        if self.throw_on_discard:
+            # The two hits do not overlap. This was a decision of the user, surely.
+            positional_overlaps: Dict[Tuple[str, str], Dict[int, int]] = {pairing: mapping for pairing, mapping in positional_overlaps.items() if mapping}
+            if len(positional_overlaps) == 0 and len(self.hits) > 1:
+                # `positional_overlaps` is always empty if there is only one hit!
+                # raise DistanceError(hits=self.hits)
+                # TODO Add way to make this fatal on request!
+                self.journal.warning(f'No positions overlap of the hits')
         unmergers: List[Unmerge] = self._get_unmerge_expansions(primary_name,
                                                                 primary_maps,
                                                                 positional_overlaps,
                                                                 min_mode_index)
+        # Nota bene:
+        # The custom map is a Dict of hit names to Dict of indices of hit to indices of followup.
+        # The Unmerge.map is a Dict of hit names to List of Dict of indices of followup to indices of hit.
+        # it is reversed in the Unmerge object.
+        if self.throw_on_discard:
+            hit_names = [h.GetProp('_Name') for h in self.hits]
+            unmergers: List[Unmerge] = [u for u in unmergers if all([h in u.maps and len(u.maps[h]) and len(u.maps[h][0]) for h in hit_names])]
+            if len(unmergers) == 0:
+                raise DistanceError(hits=self.hits)
         # -------------- Sort the unmergers --------------------------------
         self.positioned_mol, self.mol_options = self._place_unmerger_expansions(unmergers)
+        # ---- custom map sanity -----------------------------------
+        if sum(map(len, self.custom_map.values())) and not self._check_custom_map(self.positioned_mol):
+            self.journal.debug(f'Custom map sanity check failed for best candidate.')
+            for mol in self.mol_options:
+                if self._check_custom_map(self.positioned_mol):
+                    self.positioned_mol = mol
+                    break
+            else:
+                raise FragmensteinError(f'No custom map satisfied by any of the options.')
         return self.positioned_mol
 
-    def _get_primary_maps(self, primary_name:Optional[str]=None) -> Tuple[str, List[Dict[int, int]]]:
+    def _check_custom_map(self, mol: Chem.Mol) -> bool:
+        """
+        Check that the custom map is satisfied by the molecule.
+        """
+        originses: List[List[str]] = self.origin_from_mol(mol)
+        mapping: Dict[int, int]
+        for name, mapping in self.custom_map.items():
+            for hit_i, followup_i in mapping.items():
+                if followup_i < 0 and \
+                        all([(f'{name}.{hit_i}' not in origin) for origins in originses for origin in origins]):
+                    pass  # forbidden correctly — absent from all origins
+                elif followup_i < 0:  # damnation
+                    self.journal.info('Suboptimal fixing: atom is forbidden from matching, '+\
+                                      'but is matched indirectly but not constrained.')
+                    followup_i = [o for o, origins in enumerate(originses) for origin in origins if f'{name}.{hit_i}' in origin][0]
+                    mol.GetAtomWithIdx(followup_i).SetProp('_origin', 'none')
+                    mol.GetAtomWithIdx(followup_i).SetBoolProp('_Novel', True)
+                elif any([origin == f'{name}.{hit_i}' for origin in originses[followup_i]]):
+                    pass  # mapped correctly
+                elif hit_i < 0 and name not in originses[followup_i]:
+                    pass  # forbidden correctly
+                else:
+                    self.journal.info(f'Custom map sanity check failed for a combination for hit {name} idx {hit_i} '+\
+                                      f'to followup idx {followup_i} — {originses}')
+                    return False
+        return True
+
+    def _get_primary_maps(self, primary_name: Optional[str] = None) -> Tuple[str, List[Dict[int, int]]]:
         """
         The primary hit is the hit will most in common with the placed molecule.
 
@@ -58,11 +114,19 @@ class _MonsterExpand(_MonsterNone):
         self.journal.debug(f"Primary hit: {primary_name} with {len(primary_maps)} Primary maps: {primary_maps}")
         return primary_name, primary_maps
 
-    def _get_unmerge_expansions(self, primary_name, primary_maps,
-                                positional_overlaps,
-                                min_mode_index) -> List[Unmerge]:
+    def _get_unmerge_expansions(self,
+                                primary_name: str,
+                                primary_maps: List[Dict[int, int]],
+                                positional_overlaps: Dict[Tuple[str, str], Dict[int, int]],
+                                min_mode_index: int) -> List[Unmerge]:
         """
-        Calls _perform_unmerge which calls Unmerge
+        Calls _perform_unmerge which calls Unmerge.
+
+        :param primary_name: the hit name. Unlike the other methods, this is not optional.
+                for example in ``._get_primary_maps(primary_name)`` it can be None.
+        :param primary_maps: the maps for the primary hit. This is returned by ``._get_primary_maps(primary_name)``
+        :param positional_overlaps: the positional overlaps. see ``_compute_overlaps``.
+        :param min_mode_index: the minimum mode index. see ``get_mcs_mappings``, whose default is 0.
         """
         unmergers = []
         # the no_blend mode does the unmerged based on a dict of optional maps,
@@ -90,7 +154,7 @@ class _MonsterExpand(_MonsterNone):
                 other_name: str = other.GetProp('_Name')
                 if other_name == primary_name:
                     continue
-                mappings:List[Dict[int, int]]
+                mappings: List[Dict[int, int]]
                 mode: ExtendedFMCSMode
                 mappings, mode = self.get_mcs_mappings(other, self.initial_mol, min_mode_index, exp_map)
                 # drop any that are redundant with the primary hit
@@ -126,25 +190,18 @@ class _MonsterExpand(_MonsterNone):
     def _compute_overlaps(self) -> Dict[Tuple[str, str], Dict[int, int]]:
         positional_overlaps: Dict[Tuple[str, str], Dict[int, int]] = {}
         for mol1, mol2 in itertools.combinations(self.hits, 2):
-            mol1_name:str = mol1.GetProp('_Name')
-            mol2_name:str = mol2.GetProp('_Name')
+            mol1_name: str = mol1.GetProp('_Name')
+            mol2_name: str = mol2.GetProp('_Name')
             gpm = GPM.get_positional_mapping(mol1, mol2)
             positional_overlaps[(mol1_name, mol2_name)] = gpm
             positional_overlaps[(mol2_name, mol1_name)] = gpm
         return positional_overlaps
 
-
-    def _include_missing_hits(self, custom_map: Dict[str, Dict[int, int]]) -> None:
-        for hit in self.hits:
-            name = hit.GetProp('_Name')
-            if name not in custom_map:
-                custom_map[name] = {}
-
     def _expand_hit_atom_map_by_overlap(self,
-                                     hit_name: str,
-                                     hit_atom_map: Dict[int, int],
-                                     positional_overlaps: Dict[Tuple[str, str], Dict[int, int]],
-                                     custom_map: Dict[str, Dict[int, int]]) -> Dict[str, Dict[int, int]]:
+                                        hit_name: str,
+                                        hit_atom_map: Dict[int, int],
+                                        positional_overlaps: Dict[Tuple[str, str], Dict[int, int]],
+                                        custom_map: Dict[str, Dict[int, int]]) -> Dict[str, Dict[int, int]]:
         """
         Expanded the custom_map by adding all atoms that are covered by the hit_atom_map.
 
@@ -157,14 +214,14 @@ class _MonsterExpand(_MonsterNone):
         """
         expanded: Dict[str, Dict[int, int]] = deepcopy(custom_map)
         expanded[hit_name] = hit_atom_map
-        self._include_missing_hits(expanded)
+        self.fix_custom_map(expanded)
         for hit_atom_idx, template_atom_idx in hit_atom_map.items():
             for other in self.hits:
-                other_name:str = other.GetProp('_Name')
+                other_name: str = other.GetProp('_Name')
                 if other_name == hit_name:
                     continue
                 # ------------- deal with atoms that overlap --------------------------
-                overlaps: Dict[int, int] = positional_overlaps[(hit_name, other_name)]
+                overlaps: Dict[int, int] = positional_overlaps.get((hit_name, other_name), {})
                 if hit_atom_idx in overlaps:
                     # ignore the special overrides
                     if template_atom_idx < 0:
@@ -178,6 +235,5 @@ class _MonsterExpand(_MonsterNone):
                 elif template_atom_idx in expanded[other_name].values():
                     pass  # there is a mapping already ?!
                 else:  # damn the template_atom_idx
-                    expanded[other_name][-2-hit_atom_idx] = template_atom_idx
+                    expanded[other_name][-2 - hit_atom_idx] = template_atom_idx
         return expanded
-
