@@ -5,7 +5,7 @@ from rdkit.Chem import Draw, AllChem
 from matplotlib.colors import ColorConverter
 from ..branding import divergent_colors
 from functools import singledispatchmethod
-from typing import Tuple, List, Dict
+from typing import Tuple, List, Dict, Optional
 from io import StringIO
 import re
 from ..display import MolNGLWidget
@@ -73,6 +73,7 @@ class _MonsterUtilCompare:
         Store the color of the origin in the mol as the private property _color
         :return:
         """
+        # color_maps = {'benzene': {0: '#AED882', ...},..
         color_maps: Dict[str, Dict[int, str]] = self.get_color_origins()
         for hit in self.hits:  #:Chem.Mol
             name = hit.GetProp('_Name')
@@ -81,7 +82,7 @@ class _MonsterUtilCompare:
             if name not in color_maps:
                 continue
             for i in color_maps[name]:
-                hit.GetAtomWithIdx(i).SetProp('_color', color_maps[name][i])
+                hit.GetAtomWithIdx(i % 100).SetProp('_color', color_maps[name][i])
         followup_map = color_maps[self.positioned_mol.GetProp('_Name')]
         for atom in self.positioned_mol.GetAtoms():  #: Chem.Atom
             atom.SetProp('_color', '#FFFFFF')  # white
@@ -112,7 +113,7 @@ class _MonsterUtilCompare:
         draw(self.positioned_mol, followup_color_map, 300, 300)
 
 
-    def convert_origins_to_custom_map(self) -> Dict[str, Dict[int, int]]:
+    def convert_origins_to_custom_map(self, mol: Optional[Chem.Mol]=None) -> Dict[str, Dict[int, int]]:
         """
         The origins stored in the followup differ in format from the custom_map.
         The former is a list of lists of hit_name+atom_index,
@@ -120,11 +121,13 @@ class _MonsterUtilCompare:
         hit atom indices to _intended_ followup index.
         This method converts the former to the latter.
 
+        If mol is None, then self.positioned_mol is used.
+
         :return:
         """
         custom_map: Dict[str, Dict[int, int]] = {}
         # `origins_from_mol` uses self.positioned_mol by default... what if it is not set?
-        origins:List[List[str]] = self.origin_from_mol()  # noqa It is in utility
+        origins:List[List[str]] = self.origin_from_mol(mol)  # noqa It is in utility
         for hit in self.hits:  #:Chem.Mol
             name:str = hit.GetProp('_Name')
             # "default=-1-fi" is to assign a unique negative number to prevent anything mapping to the target index.
