@@ -10,6 +10,7 @@ __email__ = "matteo.ferla@gmail.com"
 __date__ = "2020 A.D."
 __license__ = "MIT"
 __citation__ = ""
+
 from ..version import __version__
 
 ########################################################################################################################
@@ -22,7 +23,7 @@ from typing import List, Union, Optional, Callable, Dict
 
 from rdkit import Chem
 from ..m_rmsd import mRMSD
-from ..monster import Monster
+from ..monster import Monster   # will become Victor.Monster
 
 
 class _VictorBase:
@@ -34,6 +35,8 @@ class _VictorBase:
     work_path = 'output'
     journal = logging.getLogger('Fragmenstein')
     journal.setLevel(logging.DEBUG)
+    # here for ease of subclassing
+    Monster = Monster
 
     covalent_definitions = [{'residue': 'CYS', 'smiles': '*SC', 'atomnames': ['CONN3', 'SG', 'CB']}]
     warhead_definitions = [{'name': 'acrylamide',
@@ -90,7 +93,7 @@ class _VictorBase:
 
     error_to_catch = ()  # Exception
 
-    remove_other_hetatms = True #remove all protein heteroatoms that are not water or ligand when loaded from PDB
+    remove_other_hetatms = True  # remove all protein heteroatoms that are not water or ligand when loaded from PDB
 
     # ================== Init ==========================================================================================
 
@@ -99,13 +102,14 @@ class _VictorBase:
                  pdb_filename: Union[None, str] = None,
                  pdb_block: Union[None, str] = None,
                  ligand_resn: str = 'LIG',
-                 ligand_resi: Union[int, str] = '1B',
+                 ligand_resi: Union[int, str, None] = None,
                  covalent_resn: str = 'CYS',  # no other option is accepted.
                  covalent_resi: Optional[Union[int, str]] = None,
                  extra_protein_constraint: Union[str] = None,
                  pose_fx: Optional[Callable] = None,
-                 monster_random_seed: Optional[int] = None
-                 ):
+                 monster_random_seed: Optional[int] = None,
+                 **settings
+                 ) -> object:
         """
         Initialise Victor in order to allow either combinations (merging/linking without a given aimed for molecule)
         or placements (using a given aimed for molecule).
@@ -120,6 +124,7 @@ class _VictorBase:
         :param extra_protein_constraint: multiline string of constraints relevant to the protein
         :param pose_fx: a function to call with pose to tweak or change something before minimising.
         :param monster_random_seed: a random seed for rdkit Embedding
+        :param settings: Not used in base version of Victor
         """
         # ## Store
         # entry attributes
@@ -131,20 +136,23 @@ class _VictorBase:
         else:
             raise ValueError('Provide a pdb_filename or pdb_block of the template')
         self.hits = hits
-        self.ligand_resn = ligand_resn.upper()
-        self.ligand_resi = ligand_resi
+        self.ligand_resn: str = ligand_resn.upper()
+        self.ligand_resi: str = ligand_resi if ligand_resi else self._get_empty_resi()
         self.covalent_resn = covalent_resn.upper()
         self.covalent_resi = covalent_resi
         self._correct_covalent_resi()  # noqa defined in plonk. todo: split into covalent and anchor residue.
         self.extra_constraint = extra_protein_constraint
         self.pose_fx = pose_fx
         self.random_seed = monster_random_seed
+        self.settings = settings  # not used for now
+        if len(self.settings) > 0:
+            self.journal.critical('settings not used in this version of Victor')
         # ## Fill by place and combine differently
         self.long_name = 'ligand'
         self.smiles = None
         # ## Filled by place
         self.merging_mode = "none_permissive"
-        self.custom_map = {}
+        self.custom_map = {}  # this will be fixed in monster by `.fix_custom_map`
         # ## Filled by combine
         self.joining_cutoff = None
         # ## Calculated
@@ -154,9 +162,9 @@ class _VictorBase:
         self.constraint = None
         self.modifications = {}
         self.unminimized_pdbblock = None
-        self.monster = Monster(hits,
-                               average_position=self.monster_average_position,
-                               random_seed=self.random_seed)
+        self.monster = self.Monster(hits,
+                                    average_position=self.monster_average_position,
+                                    random_seed=self.random_seed)
         self.monster.throw_on_discard = self.monster_throw_on_discard
         self.igor = None
         self.unbound_pose = None
