@@ -255,6 +255,7 @@ class _VictorUtils(_VictorShow):  # _VictorCommon -> _VictorShow
         This is however often a pdb. This converts.
         `igor.mol_from_pose()` is similar but works on a pose. `_fix_minimized()` calls ``mol_from_pose``
         and ``copy_bonds_by_atomnames`` which does not destroy pdbinfo.
+        The latter is glitchy. Use ``combine_for_bondorder``.
 
         See ``extract_mol`` for single.
 
@@ -516,3 +517,16 @@ class _VictorUtils(_VictorShow):  # _VictorCommon -> _VictorShow
                                                replacement=Chem.MolFromSmiles(warhead_def['noncovalent'])
                                                )  # noqa it is filled.
         return Chem.MolToSmiles(unrxn_mols[0]), warhead_def['name']
+
+    def get_plip_interactions(self):
+        """
+        Optional, but useful to have.
+        Get the interactions from PLIP.
+        """
+        from .plip import PLIPper
+        plipper = PLIPper(pdb_block=self.minimized_pdbblock,
+                          resn=self.ligand_resn,
+                          resi=int(self.ligand_resi[:-1]),
+                          chain=self.ligand_resi[-1])
+        setattr(self, 'plipper', plipper)  # new attribute
+        return plipper.interaction_counts
